function krog(x,y,r)

% Funkcija KROG(x,y,r) narise krog z radijem r okrog tocke (x,y).
%
% Argumenti:
%   x = x koordinata sredisca
%   y = y koordinata sredisca
%   r = radij kroga
%

% Bor Plestenjak
% 2.10.1996 

t=0:0.2:2*pi;
plot(x+r*cos(t),y+r*sin(t))